@@ -57,7 +57,7 @@ impl ExecService {
                 };
 
                 return Ok(Err(value));
-            } else if calls[clock] == OP_JUMP {
+            } else if calls[clock] == OP_GOTO {
                 let value = match calls.get(clock + 1) {
                     Some(some) => *some,
                     None => return Err(Error::from(format!("invalid address `{}`", clock + 1)))
@@ -72,6 +72,21 @@ impl ExecService {
                 }
 
                 clock = value as usize;
+            } else if calls[clock] == OP_JUMP {
+                let value = match calls.get(clock + 1) {
+                    Some(some) => *some,
+                    None => return Err(Error::from(format!("invalid address `{}`", clock + 1)))
+                };
+
+                if value as usize >= calls.len() {
+                    return Err(Error::from(format!("invalid address `{}`", value)));
+                }
+                
+                if value < 0 {
+                    clock = clock - flip(value) as usize;
+                } else {
+                    clock = clock + value as usize;
+                }
             }
         }
 
