@@ -6,6 +6,7 @@ pub mod exec;
 pub mod io;
 pub mod stack;
 pub mod opcode;
+pub mod math;
 
 pub use mem::*;
 pub use byte::*;
@@ -13,6 +14,7 @@ pub use exec::*;
 pub use io::{*, Handle::*};
 pub use stack::*;
 pub use opcode::*;
+pub use math::*;
 
 #[cfg(test)]
 mod tests;
