@@ -2,4 +2,5 @@ use super::*;
 
 pub const OP_RETURN: Byte = 0x6A;
 pub const OP_THROW: Byte = 0x4C;
-pub const OP_JUMP: Byte = 0x5B;
+pub const OP_GOTO: Byte = 0x5B;
+pub const OP_JUMP: Byte = 0x5C;
